@@ -1,7 +1,7 @@
 <?php
 
 /**
- *  Class for operations on Sieve scripts
+ * Class for operations on Sieve scripts
  *
  * Copyright (C) 2008-2011, The Roundcube Dev Team
  * Copyright (C) 2011, Kolab Systems AG
@@ -24,21 +24,22 @@ class rcube_sieve_script
 {
     public $content = array();      // script rules array
 
-    private $vars = array();        // "global" variables
-    private $prefix = '';           // script header (comments)
-    private $supported = array(     // Sieve extensions supported by class
+    private $vars      = array();   // "global" variables
+    private $prefix    = '';        // script header (comments)
+    private $supported = array(     // supported Sieve extensions:
         'body',                     // RFC5173
         'copy',                     // RFC3894
         'date',                     // RFC5260
+        'duplicate',                // RFC7352
         'enotify',                  // RFC5435
         'envelope',                 // RFC5228
         'ereject',                  // RFC5429
         'fileinto',                 // RFC5228
         'imapflags',                // draft-melnikov-sieve-imapflags-06
         'imap4flags',               // RFC5232
-        'include',                  // draft-ietf-sieve-include-12
+        'include',                  // RFC6609
         'index',                    // RFC5260
-        'notify',                   // draft-martin-sieve-notify-01,
+        'notify',                   // RFC5435
         'regex',                    // draft-ietf-sieve-regex-01
         'reject',                   // RFC5429
         'relational',               // RFC3431
@@ -84,21 +85,22 @@ class rcube_sieve_script
     {
         // TODO: check this->supported
         array_push($this->content, $content);
-        return sizeof($this->content)-1;
+        return count($this->content) - 1;
     }
 
     public function delete_rule($index)
     {
-        if(isset($this->content[$index])) {
+        if (isset($this->content[$index])) {
             unset($this->content[$index]);
             return true;
         }
+
         return false;
     }
 
     public function size()
     {
-        return sizeof($this->content);
+        return count($this->content);
     }
 
     public function update_rule($index, $content)
@@ -108,6 +110,7 @@ class rcube_sieve_script
             $this->content[$index] = $content;
             return $index;
         }
+
         return false;
     }
 
@@ -237,8 +240,13 @@ class rcube_sieve_script
                         break;
 
                     case 'header':
+                    case 'string':
+                        if ($test['test'] == 'string') {
+                            array_push($exts, 'variables');
+                        }
+
                         $tests[$i] .= ($test['not'] ? 'not ' : '');
-                        $tests[$i] .= 'header';
+                        $tests[$i] .= $test['test'];
 
                         $this->add_index($test, $tests[$i], $exts);
                         $this->add_operator($test, $tests[$i], $exts);
@@ -316,8 +324,30 @@ class rcube_sieve_script
                         $tests[$i] .= ' ' . self::escape_string($test['part']);
                         $tests[$i] .= ' ' . self::escape_string($test['arg']);
 
+                        break;
+
+                    case 'duplicate':
+                        array_push($exts, 'duplicate');
+
+                        $tests[$i] .= ($test['not'] ? 'not ' : '') . $test['test'];
+
+                        $tokens = array('handle', 'uniqueid', 'header');
+                        foreach ($tokens as $token)
+                            if ($test[$token] !== null && $test[$token] !== '') {
+                                $tests[$i] .= " :$token " . self::escape_string($test[$token]);
+                            }
+
+                        if (!empty($test['seconds'])) {
+                            $tests[$i] .= ' :seconds ' . intval($test['seconds']);
+                        }
+
+                        if (!empty($test['last'])) {
+                            $tests[$i] .= ' :last';
+                        }
+
                         break;
                     }
+
                     $i++;
                 }
             }
@@ -685,6 +715,7 @@ class rcube_sieve_script
                 break;
 
             case 'header':
+            case 'string':
             case 'address':
             case 'envelope':
                 $test = array('test' => $token, 'not' => $not);
@@ -694,7 +725,7 @@ class rcube_sieve_script
 
                 $test += $this->test_tokens($tokens);
 
-                if ($token != 'header' && !empty($tokens)) {
+                if ($token != 'header' && $token != 'string' && !empty($tokens)) {
                     for ($i=0, $len=count($tokens); $i<$len; $i++) {
                         if (!is_array($tokens[$i]) && preg_match('/^:(localpart|domain|all|user|detail)$/i', $tokens[$i])) {
                             $test['part'] = strtolower(substr($tokens[$i], 1));
@@ -750,6 +781,23 @@ class rcube_sieve_script
                 $tests[] = $test;
                 break;
 
+            case 'duplicate':
+                $test = array('test' => $token, 'not' => $not);
+
+                for ($i=0, $len=count($tokens); $i<$len; $i++) {
+                    if (!is_array($tokens[$i])) {
+                        if (preg_match('/^:(handle|header|uniqueid|seconds)$/i', $tokens[$i], $m)) {
+                            $test[strtolower($m[1])] = $tokens[++$i];
+                        }
+                        else if (preg_match('/^:last$/i', $tokens[$i])) {
+                            $test['last'] = true;
+                        }
+                    }
+                }
+
+                $tests[] = $test;
+                break;
+
             case 'exists':
                 $tests[] = array('test' => 'exists', 'not' => $not,
                     'arg'  => array_pop($tokens));
@@ -973,33 +1021,25 @@ class rcube_sieve_script
         $result = array();
 
         for ($i=0, $len=count($tokens); $i<$len; $i++) {
-            if (!is_array($tokens[$i]) && $tokens[$i][0] == ':') {
-                if (preg_match('/^:comparator$/i', $tokens[$i])) {
-                    $test['comparator'] = $tokens[++$i];
-                    continue;
-                }
-
-                if (preg_match('/^:(count|value)$/i', $tokens[$i])) {
-                    $test['type'] = strtolower(substr($tokens[$i], 1)) . '-' . $tokens[++$i];
-                    continue;
-                }
-
-                if (preg_match('/^:(is|contains|matches|regex)$/i', $tokens[$i])) {
-                    $test['type'] = strtolower(substr($tokens[$i], 1));
-                    continue;
-                }
-
-                if (preg_match('/^:index$/i', $tokens[$i])) {
-                    $test['index'] = intval($tokens[++$i]);
-                    if ($tokens[$i+1] && preg_match('/^:last$/i', $tokens[$i+1])) {
-                        $test['last'] = true;
-                        $i++;
-                    }
-                    continue;
-                }
+            if (!is_array($tokens[$i]) && preg_match('/^:comparator$/i', $tokens[$i])) {
+                $test['comparator'] = $tokens[++$i];
             }
-
-            $result[] = $tokens[$i];
+            else if (!is_array($tokens[$i]) && preg_match('/^:(count|value)$/i', $tokens[$i])) {
+                $test['type'] = strtolower(substr($tokens[$i], 1)) . '-' . $tokens[++$i];
+            }
+            else if (!is_array($tokens[$i]) && preg_match('/^:(is|contains|matches|regex)$/i', $tokens[$i])) {
+                $test['type'] = strtolower(substr($tokens[$i], 1));
+            }
+            else if (!is_array($tokens[$i]) && preg_match('/^:index$/i', $tokens[$i])) {
+                $test['index'] = intval($tokens[++$i]);
+                if ($tokens[$i+1] && preg_match('/^:last$/i', $tokens[$i+1])) {
+                    $test['last'] = true;
+                    $i++;
+                }
+           }
+           else {
+               $result[] = $tokens[$i];
+           }
         }
 
         $tokens = $result;
@@ -1050,7 +1090,7 @@ class rcube_sieve_script
     static function escape_string($str)
     {
         if (is_array($str) && count($str) > 1) {
-            foreach($str as $idx => $val)
+            foreach ($str as $idx => $val)
                 $str[$idx] = self::escape_string($val);
 
             return '[' . implode(',', $str) . ']';
@@ -1105,7 +1145,6 @@ class rcube_sieve_script
     {
         $result = array();
         $length = strlen($str);
-        $mask   = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789:_';
 
         // remove spaces from the beginning of the string
         while ($position < $length && (!$num || $num === true || count($result) < $num)) {
@@ -1191,11 +1230,18 @@ class rcube_sieve_script
                 if ($position == $length) {
                     break 2;
                 }
+                if ($length - $position < 2) {
+                    $result[] = substr($str, $position);
+                    $position = $length;
+                    break;
+                }
 
                 // tag/identifier/number
-                if ($len = strspn($str, $mask, $position)) {
-                    $atom      = substr($str, $position, $len);
-                    $position += $len;
+                if (preg_match('/[a-zA-Z0-9:_]+/', $str, $m, PREG_OFFSET_CAPTURE, $position)
+                    && $m[0][1] == $position
+                ) {
+                    $atom      = $m[0][0];
+                    $position += strlen($atom);
 
                     if ($atom != 'text:') {
                         $result[] = $atom;
@@ -1231,11 +1277,16 @@ class rcube_sieve_script
                             $text    .= substr($str, $position, $pos - $position);
                             $position = $pos + 2;
 
-                            if ($str[$pos] == "\n"
-                                || ($str[$pos] == "\r" && $str[$pos + 1] == "\n")
-                            ) {
+                            if ($str[$position] == "\n") {
                                 break;
                             }
+
+                            if ($str[$position] == "\r" && $str[$position + 1] == "\n") {
+                                $position++;
+                                break;
+                            }
+
+                            $text .= "\n.";
                         }
 
                         // remove dot-stuffing
