@@ -138,18 +138,19 @@ class rcmail extends rcube
     /**
      * Setter for application task
      *
-     * @param string Task to set
+     * @param string $task Task to set
      */
     public function set_task($task)
     {
-        $task = asciiwords($task, true);
-
-        if ($this->user && $this->user->ID)
-            $task = !$task ? 'mail' : $task;
-        else if (php_sapi_name() == 'cli')
+        if (php_sapi_name() == 'cli') {
             $task = 'cli';
-        else
+        }
+        else if (!$this->user || !$this->user->ID) {
             $task = 'login';
+        }
+        else {
+            $task = asciiwords($task, true) ?: 'mail';
+        }
 
         $this->task      = $task;
         $this->comm_path = $this->url(array('task' => $this->task));
@@ -167,7 +168,7 @@ class rcmail extends rcube
     /**
      * Setter for system user object
      *
-     * @param rcube_user Current user instance
+     * @param rcube_user $user Current user instance
      */
     public function set_user($user)
     {
@@ -190,8 +191,8 @@ class rcmail extends rcube
     /**
      * Return instance of the internal address book class
      *
-     * @param string  Address book identifier (-1 for default addressbook)
-     * @param boolean True if the address book needs to be writeable
+     * @param string  $id        Address book identifier (-1 for default addressbook)
+     * @param boolean $writeable True if the address book needs to be writeable
      *
      * @return rcube_contacts Address book object
      */
@@ -280,7 +281,7 @@ class rcmail extends rcube
     /**
      * Return identifier of the address book object
      *
-     * @param rcube_addressbook Addressbook source object
+     * @param rcube_addressbook $object Addressbook source object
      *
      * @return string Source identifier
      */
@@ -296,10 +297,10 @@ class rcmail extends rcube
     /**
      * Return address books list
      *
-     * @param boolean True if the address book needs to be writeable
-     * @param boolean True if the address book needs to be not hidden
+     * @param boolean $writeable   True if the address book needs to be writeable
+     * @param boolean $skip_hidden True if the address book needs to be not hidden
      *
-     * @return array  Address books array
+     * @return array Address books array
      */
     public function get_address_sources($writeable = false, $skip_hidden = false)
     {
@@ -367,8 +368,8 @@ class rcmail extends rcube
      * Getter for compose responses.
      * These are stored in local config and user preferences.
      *
-     * @param boolean True to sort the list alphabetically
-     * @param boolean True if only this user's responses shall be listed
+     * @param boolean $sorted    True to sort the list alphabetically
+     * @param boolean $user_only True if only this user's responses shall be listed
      *
      * @return array List of the current user's stored responses
      */
@@ -379,13 +380,13 @@ class rcmail extends rcube
         if (!$user_only) {
             foreach ($this->config->get('compose_responses_static', array()) as $response) {
                 if (empty($response['key'])) {
-                    $response['key']    = substr(md5($response['name']), 0, 16);
+                    $response['key'] = substr(md5($response['name']), 0, 16);
                 }
 
                 $response['static'] = true;
                 $response['class']  = 'readonly';
 
-                $k = $sorted ? '0000-' . strtolower($response['name']) : $response['key'];
+                $k = $sorted ? '0000-' . mb_strtolower($response['name']) : $response['key'];
                 $responses[$k] = $response;
             }
         }
@@ -395,7 +396,7 @@ class rcmail extends rcube
                 $response['key'] = substr(md5($response['name']), 0, 16);
             }
 
-            $k = $sorted ? strtolower($response['name']) : $response['key'];
+            $k = $sorted ? mb_strtolower($response['name']) : $response['key'];
             $responses[$k] = $response;
         }
 
@@ -404,7 +405,15 @@ class rcmail extends rcube
             ksort($responses, SORT_LOCALE_STRING);
         }
 
-        return array_values($responses);
+        $responses = array_values($responses);
+
+        $hook = $this->plugins->exec_hook('get_compose_responses', array(
+            'list'      => $responses,
+            'sorted'    => $sorted,
+            'user_only' => $user_only,
+        ));
+
+        return $hook['list'];
     }
 
     /**
@@ -412,7 +421,7 @@ class rcmail extends rcube
      * This will instantiate a rcmail_output_html object and set
      * environment vars according to the current session and configuration
      *
-     * @param boolean True if this request is loaded in a (i)frame
+     * @param boolean $framed True if this request is loaded in a (i)frame
      *
      * @return rcube_output Reference to HTML output object
      */
@@ -446,7 +455,7 @@ class rcmail extends rcube
 
         // add some basic labels to client
         $this->output->add_label('loading', 'servererror', 'connerror', 'requesttimedout',
-            'refreshing', 'windowopenerror', 'uploadingmany');
+            'refreshing', 'windowopenerror', 'uploadingmany', 'close');
 
         return $this->output;
     }
@@ -484,13 +493,13 @@ class rcmail extends rcube
     }
 
     /**
-     * Perfom login to the mail server and to the webmail service.
+     * Perform login to the mail server and to the webmail service.
      * This will also create a new user entry if auto_create_user is configured.
      *
-     * @param string Mail storage (IMAP) user name
-     * @param string Mail storage (IMAP) password
-     * @param string Mail storage (IMAP) host
-     * @param bool   Enables cookie check
+     * @param string $username    Mail storage (IMAP) user name
+     * @param string $password    Mail storage (IMAP) password
+     * @param string $host        Mail storage (IMAP) host
+     * @param bool   $cookiecheck Enables cookie check
      *
      * @return boolean True on success, False on failure
      */
@@ -528,8 +537,8 @@ class rcmail extends rcube
         // we'll only handle unset host (if possible)
         if (!$host && !empty($default_host)) {
             if (is_array($default_host)) {
-                list($key, $val) = each($default_host);
-                $host = is_numeric($key) ? $val : $key;
+                $key  = key($default_host);
+                $host = is_numeric($key) ? $default_host[$key] : $key;
             }
             else {
                 $host = $default_host;
@@ -740,8 +749,8 @@ class rcmail extends rcube
 
             // take the first entry if $host is still not set
             if (empty($host)) {
-                list($key, $val) = each($default_host);
-                $host = is_numeric($key) ? $val : $key;
+                $key  = key($default_host);
+                $host = is_numeric($key) ? $default_host[$key] : $key;
             }
         }
         else if (empty($default_host)) {
@@ -793,10 +802,11 @@ class rcmail extends rcube
     /**
      * Build a valid URL to this instance of Roundcube
      *
-     * @param mixed   Either a string with the action or url parameters as key-value pairs
-     * @param boolean Build an URL absolute to document root
-     * @param boolean Create fully qualified URL including http(s):// and hostname
-     * @param bool    Return absolute URL in secure location
+     * @param mixed   $p        Either a string with the action or
+     *                          url parameters as key-value pairs
+     * @param boolean $absolute Build an URL absolute to document root
+     * @param boolean $full     Create fully qualified URL including http(s):// and hostname
+     * @param bool    $secure   Return absolute URL in secure location
      *
      * @return string Valid application URL
      */
@@ -870,8 +880,9 @@ class rcmail extends rcube
         parent::shutdown();
 
         foreach ($this->address_books as $book) {
-            if (is_object($book) && is_a($book, 'rcube_addressbook'))
+            if (is_object($book) && is_a($book, 'rcube_addressbook')) {
                 $book->close();
+            }
         }
 
         // write performance stats to logs/console
@@ -879,39 +890,41 @@ class rcmail extends rcube
             // make sure logged numbers use unified format
             setlocale(LC_NUMERIC, 'en_US.utf8', 'en_US.UTF-8', 'en_US', 'C');
 
-            if (function_exists('memory_get_usage'))
+            if (function_exists('memory_get_usage')) {
                 $mem = $this->show_bytes(memory_get_usage());
-            if (function_exists('memory_get_peak_usage'))
+            }
+            if (function_exists('memory_get_peak_usage')) {
                 $mem .= '/'.$this->show_bytes(memory_get_peak_usage());
+            }
 
             $log = $this->task . ($this->action ? '/'.$this->action : '') . ($mem ? " [$mem]" : '');
 
-            if (defined('RCMAIL_START'))
+            if (defined('RCMAIL_START')) {
                 self::print_timer(RCMAIL_START, $log);
-            else
+            }
+            else {
                 self::console($log);
+            }
         }
     }
 
     /**
-     * CSRF attack prevention code
+     * CSRF attack prevention code. Raises error when check fails.
      *
-     * @param int Request mode
+     * @param int $mode Request mode
      */
     public function request_security_check($mode = rcube_utils::INPUT_POST)
     {
         // check request token
         if (!$this->check_request($mode)) {
-            self::raise_error(array(
-                'code' => 403, 'type' => 'php',
-                'message' => "Request security check failed"), false, true);
+            $error = array('code' => 403, 'message' => "Request security check failed");
+            self::raise_error($error, false, true);
         }
 
         // check referer if configured
         if ($this->config->get('referer_check') && !rcube_utils::check_referer()) {
-            self::raise_error(array(
-                'code' => 403, 'type' => 'php',
-                'message' => "Referer check failed"), true, true);
+            $error = array('code' => 403, 'message' => "Referer check failed");
+            self::raise_error($error, true, true);
         }
     }
 
@@ -1044,7 +1057,7 @@ class rcmail extends rcube
     /**
      * Overwrite action variable
      *
-     * @param string New action value
+     * @param string $action New action value
      */
     public function overwrite_action($action)
     {
@@ -1054,6 +1067,8 @@ class rcmail extends rcube
 
     /**
      * Set environment variables for specified config options
+     *
+     * @param array $options List of configuration option names
      */
     public function set_env_config($options)
     {
@@ -1123,20 +1138,21 @@ class rcmail extends rcube
     /**
      * Create a HTML table based on the given data
      *
-     * @param  array  Named table attributes
-     * @param  mixed  Table row data. Either a two-dimensional array or a valid SQL result set
-     * @param  array  List of cols to show
-     * @param  string Name of the identifier col
+     * @param array  $attrib     Named table attributes
+     * @param mixed  $table_data Table row data. Either a two-dimensional array
+     *                           or a valid SQL result set
+     * @param array  $show_cols  List of cols to show
+     * @param string $id_col     Name of the identifier col
      *
      * @return string HTML table code
      */
-    public function table_output($attrib, $table_data, $a_show_cols, $id_col)
+    public function table_output($attrib, $table_data, $show_cols, $id_col)
     {
         $table = new html_table($attrib);
 
         // add table header
         if (!$attrib['noheader']) {
-            foreach ($a_show_cols as $col) {
+            foreach ($show_cols as $col) {
                 $table->add_header($col, $this->Q($this->gettext($col)));
             }
         }
@@ -1147,7 +1163,7 @@ class rcmail extends rcube
                 $table->add_row(array('id' => 'rcmrow' . rcube_utils::html_identifier($sql_arr[$id_col])));
 
                 // format each col
-                foreach ($a_show_cols as $col) {
+                foreach ($show_cols as $col) {
                     $table->add($col, $this->Q($sql_arr[$col]));
                 }
             }
@@ -1162,7 +1178,7 @@ class rcmail extends rcube
                 $table->add_row(array('id' => $rowid, 'class' => $class));
 
                 // format each col
-                foreach ($a_show_cols as $col) {
+                foreach ($show_cols as $col) {
                     $val = is_array($row_data[$col]) ? $row_data[$col][0] : $row_data[$col];
                     $table->add($col, empty($attrib['ishtml']) ? $this->Q($val) : $val);
                 }
@@ -1176,9 +1192,9 @@ class rcmail extends rcube
      * Convert the given date to a human readable form
      * This uses the date formatting properties from config
      *
-     * @param mixed  Date representation (string, timestamp or DateTime object)
-     * @param string Date format to use
-     * @param bool   Enables date convertion according to user timezone
+     * @param mixed  $date    Date representation (string, timestamp or DateTime object)
+     * @param string $format  Date format to use
+     * @param bool   $convert Enables date conversion according to user timezone
      *
      * @return string Formatted date string
      */
@@ -1314,12 +1330,6 @@ class rcmail extends rcube
 
         $attrib += array('maxlength' => 100, 'realnames' => false, 'unreadwrap' => ' (%s)');
 
-        $rcmail  = rcmail::get_instance();
-        $storage = $rcmail->get_storage();
-
-        // add some labels to client
-        $rcmail->output->add_label('purgefolderconfirm', 'deletemessagesconfirm');
-
         $type = $attrib['type'] ? $attrib['type'] : 'ul';
         unset($attrib['type']);
 
@@ -1332,6 +1342,7 @@ class rcmail extends rcube
         }
 
         // get current folder
+        $storage   = $this->get_storage();
         $mbox_name = $storage->get_folder();
 
         // build the folders tree
@@ -1343,12 +1354,12 @@ class rcmail extends rcube
             $a_mailboxes = array();
 
             foreach ($a_folders as $folder) {
-                $rcmail->build_folder_tree($a_mailboxes, $folder, $delimiter);
+                $this->build_folder_tree($a_mailboxes, $folder, $delimiter);
             }
         }
 
         // allow plugins to alter the folder tree or to localize folder names
-        $hook = $rcmail->plugins->exec_hook('render_mailboxlist', array(
+        $hook = $this->plugins->exec_hook('render_mailboxlist', array(
             'list'      => $a_mailboxes,
             'delimiter' => $delimiter,
             'type'      => $type,
@@ -1364,39 +1375,42 @@ class rcmail extends rcube
 
             // add no-selection option
             if ($attrib['noselection']) {
-                $select->add(html::quote($rcmail->gettext($attrib['noselection'])), '');
+                $select->add(html::quote($this->gettext($attrib['noselection'])), '');
             }
 
-            $rcmail->render_folder_tree_select($a_mailboxes, $mbox_name, $attrib['maxlength'], $select, $attrib['realnames']);
+            $this->render_folder_tree_select($a_mailboxes, $mbox_name, $attrib['maxlength'], $select, $attrib['realnames']);
             $out = $select->show($attrib['default']);
         }
         else {
             $js_mailboxlist = array();
-            $tree = $rcmail->render_folder_tree_html($a_mailboxes, $mbox_name, $js_mailboxlist, $attrib);
+            $tree = $this->render_folder_tree_html($a_mailboxes, $mbox_name, $js_mailboxlist, $attrib);
 
             if ($type != 'js') {
                 $out = html::tag('ul', $attrib, $tree, html::$common_attrib);
 
-                $rcmail->output->include_script('treelist.js');
-                $rcmail->output->add_gui_object('mailboxlist', $attrib['id']);
-                $rcmail->output->set_env('unreadwrap', $attrib['unreadwrap']);
-                $rcmail->output->set_env('collapsed_folders', (string)$rcmail->config->get('collapsed_folders'));
+                $this->output->include_script('treelist.js');
+                $this->output->add_gui_object('mailboxlist', $attrib['id']);
+                $this->output->set_env('unreadwrap', $attrib['unreadwrap']);
+                $this->output->set_env('collapsed_folders', (string) $this->config->get('collapsed_folders'));
             }
 
-            $rcmail->output->set_env('mailboxes', $js_mailboxlist);
+            $this->output->set_env('mailboxes', $js_mailboxlist);
 
             // we can't use object keys in javascript because they are unordered
             // we need sorted folders list for folder-selector widget
-            $rcmail->output->set_env('mailboxes_list', array_keys($js_mailboxlist));
+            $this->output->set_env('mailboxes_list', array_keys($js_mailboxlist));
         }
 
+        // add some labels to client
+        $this->output->add_label('purgefolderconfirm', 'deletemessagesconfirm');
+
         return $out;
     }
 
     /**
      * Return folders list as html_select object
      *
-     * @param array $p  Named parameters
+     * @param array $p Named parameters
      *
      * @return html_select HTML drop-down object
      */
@@ -1568,19 +1582,20 @@ class rcmail extends rcube
                 $classes[] = 'unread';
             }
 
-            $js_name = $this->JQ($folder['id']);
-            $html_name = $this->Q($foldername) . ($unread ? html::span('unreadcount', sprintf($attrib['unreadwrap'], $unread)) : '');
+            $js_name     = $this->JQ($folder['id']);
+            $html_name   = $this->Q($foldername) . ($unread ? html::span('unreadcount', sprintf($attrib['unreadwrap'], $unread)) : '');
             $link_attrib = $folder['virtual'] ? array() : array(
-                'href' => $this->url(array('_mbox' => $folder['id'])),
+                'href'    => $this->url(array('_mbox' => $folder['id'])),
                 'onclick' => sprintf("return %s.command('list','%s',this,event)", rcmail_output::JS_OBJECT_NAME, $js_name),
-                'rel' => $folder['id'],
-                'title' => $title,
+                'rel'     => $folder['id'],
+                'title'   => $title,
             );
 
             $out .= html::tag('li', array(
-                'id' => "rcmli".$folder_id,
-                'class' => join(' ', $classes),
-                'noclose' => true),
+                    'id'      => "rcmli" . $folder_id,
+                    'class'   => join(' ', $classes),
+                    'noclose' => true
+                ),
                 html::a($link_attrib, $html_name));
 
             if (!empty($folder['folders'])) {
@@ -1708,7 +1723,9 @@ class rcmail extends rcube
                     $folder = implode($delimiter, array_slice($path, 0, -$i));
                     if ($folder_class = $this->folder_classname($folder)) {
                         $name = implode($delimiter, array_slice($path, $count - $i));
-                        return $this->gettext($folder_class) . $delimiter . rcube_charset::convert($name, 'UTF7-IMAP');
+                        $name = rcube_charset::convert($name, 'UTF7-IMAP');
+
+                        return $this->gettext($folder_class) . $delimiter . $name;
                     }
                 }
             }
@@ -1717,7 +1734,9 @@ class rcmail extends rcube
         return rcube_charset::convert($name, 'UTF7-IMAP');
     }
 
-
+    /**
+     * Localize folder path
+     */
     public function localize_folderpath($path)
     {
         $protect_folders = $this->config->get('protect_default_folders');
@@ -1739,7 +1758,13 @@ class rcmail extends rcube
         return implode($delimiter, $result);
     }
 
-
+    /**
+     * Return HTML for quota indicator object
+     *
+     * @param array $attrib Named parameters
+     *
+     * @return string HTML code for the quota indicator object
+     */
     public static function quota_display($attrib)
     {
         $rcmail = rcmail::get_instance();
@@ -1759,13 +1784,20 @@ class rcmail extends rcube
         return html::span($attrib, '&nbsp;');
     }
 
-
+    /**
+     * Return (parsed) quota information
+     *
+     * @param array $attrib Named parameters
+     * @param array $folder Current folder
+     *
+     * @return array Quota information
+     */
     public function quota_content($attrib = null, $folder = null)
     {
         $quota = $this->storage->get_quota($folder);
         $quota = $this->plugins->exec_hook('quota', $quota);
 
-        $quota_result = (array) $quota;
+        $quota_result           = (array) $quota;
         $quota_result['type']   = isset($_SESSION['quota_display']) ? $_SESSION['quota_display'] : '';
         $quota_result['folder'] = $folder !== null && $folder !== '' ? $folder : 'INBOX';
 
@@ -1775,8 +1807,10 @@ class rcmail extends rcube
             }
 
             $title = sprintf('%s / %s (%.0f%%)',
-                $this->show_bytes($quota['used'] * 1024), $this->show_bytes($quota['total'] * 1024),
-                $quota_result['percent']);
+                $this->show_bytes($quota['used'] * 1024),
+                $this->show_bytes($quota['total'] * 1024),
+                $quota_result['percent']
+            );
 
             $quota_result['title'] = $title;
 
@@ -1837,10 +1871,10 @@ class rcmail extends rcube
     /**
      * Outputs error message according to server error/response codes
      *
-     * @param string $fallback       Fallback message label
-     * @param array  $fallback_args  Fallback message label arguments
-     * @param string $suffix         Message label suffix
-     * @param array  $params         Additional parameters (type, prefix)
+     * @param string $fallback      Fallback message label
+     * @param array  $fallback_args Fallback message label arguments
+     * @param string $suffix        Message label suffix
+     * @param array  $params        Additional parameters (type, prefix)
      */
     public function display_server_error($fallback = null, $fallback_args = null, $suffix = '', $params = array())
     {
@@ -1899,7 +1933,7 @@ class rcmail extends rcube
     /**
      * Output HTML editor scripts
      *
-     * @param string $mode  Editor mode
+     * @param string $mode Editor mode
      */
     public function html_editor($mode = '')
     {
@@ -1958,7 +1992,7 @@ class rcmail extends rcube
 
         $this->output->add_label('selectimage', 'addimage', 'selectmedia', 'addmedia');
         $this->output->set_env('editor_config', $config);
-        $this->output->include_css('program/js/tinymce/roundcube/browser.css');
+        $this->output->include_css('program/resources/tinymce/browser.css');
         $this->output->include_script('tinymce/tinymce.min.js');
         $this->output->include_script('editor.js');
     }
@@ -2041,7 +2075,9 @@ class rcmail extends rcube
     /**
      * Initializes file uploading interface.
      *
-     * @param $int Optional maximum file size in bytes
+     * @param int $max_size Optional maximum file size in bytes
+     *
+     * @return string Human-readable file size limit
      */
     public function upload_init($max_size = null)
     {
@@ -2069,12 +2105,92 @@ class rcmail extends rcube
             $max_filesize = $max_size;
         }
 
+        $max_filesize_txt = $this->show_bytes($max_filesize);
         $this->output->set_env('max_filesize', $max_filesize);
-        $max_filesize = $this->show_bytes($max_filesize);
         $this->output->set_env('filesizeerror', $this->gettext(array(
-            'name' => 'filesizeerror', 'vars' => array('size' => $max_filesize))));
+            'name' => 'filesizeerror', 'vars' => array('size' => $max_filesize_txt))));
 
-        return $max_filesize;
+        if ($max_filecount = ini_get('max_file_uploads')) {
+            $this->output->set_env('max_filecount', $max_filecount);
+            $this->output->set_env('filecounterror', $this->gettext(array(
+                'name' => 'filecounterror', 'vars' => array('count' => $max_filecount))));
+        }
+
+        return $max_filesize_txt;
+    }
+
+    /**
+     * Upload form object
+     *
+     * @param array  $attrib     Object attributes
+     * @param string $name       Form object name
+     * @param string $action     Form action name
+     * @param array  $input_attr File input attributes
+     *
+     * @return string HTML output
+     */
+    public function upload_form($attrib, $name, $action, $input_attr = array())
+    {
+        // Get filesize, enable upload progress bar
+        $max_filesize = $this->upload_init();
+
+        $hint = html::div('hint', $this->gettext(array('name' => 'maxuploadsize', 'vars' => array('size' => $max_filesize))));
+
+        if ($attrib['mode'] == 'hint') {
+            return $hint;
+        }
+
+        // set defaults
+        $attrib += array('id' => 'rcmUploadbox', 'buttons' => 'yes');
+
+        $event   = rcmail_output::JS_OBJECT_NAME . ".command('$action', this.form)";
+        $form_id = $attrib['id'] . 'Frm';
+
+        // Default attributes of file input and form
+        $input_attr += array(
+            'id'   => $attrib['id'] . 'Input',
+            'type' => 'file',
+            'name' => '_attachments[]',
+        );
+
+        $form_attr = array(
+            'id'      => $form_id,
+            'name'    => $name,
+            'method'  => 'post',
+            'enctype' => 'multipart/form-data'
+        );
+
+        if ($attrib['mode'] == 'smart') {
+            unset($attrib['buttons']);
+            $form_attr['class'] = 'smart-upload';
+            $input_attr = array_merge($input_attr, array(
+                // #5854: Chrome does not execute onchange when selecting the same file.
+                //        To fix this we reset the input using null value.
+                'onchange' => "$event; this.value=null",
+                'class'    => 'smart-upload',
+                'tabindex' => '-1',
+            ));
+        }
+
+        $input   = new html_inputfield($input_attr);
+        $content = $attrib['prefix'] . $input->show();
+
+        if ($attrib['mode'] != 'smart') {
+            $content  = html::div(null, $content);
+            $content .= $hint;
+        }
+
+        if (rcube_utils::get_boolean($attrib['buttons'])) {
+            $button   = new html_inputfield(array('type' => 'button'));
+            $content .= html::div('buttons',
+                $button->show($this->gettext('close'), array('class' => 'button', 'onclick' => "$('#{$attrib['id']}').hide()")) . ' ' .
+                $button->show($this->gettext('upload'), array('class' => 'button mainaction', 'onclick' => $event))
+            );
+        }
+
+        $this->output->add_gui_object($name, $form_id);
+
+        return html::div($attrib, $this->output->form_tag($form_attr, $content));
     }
 
     /**
@@ -2273,9 +2389,9 @@ class rcmail extends rcube
     /**
      * Returns message UID(s) and IMAP folder(s) from GET/POST data
      *
-     * @param string UID value to decode
-     * @param string Default mailbox value (if not encoded in UIDs)
-     * @param bool   Will be set to True if multi-folder request
+     * @param string $uids           UID value to decode
+     * @param string $mbox           Default mailbox value (if not encoded in UIDs)
+     * @param bool   $is_multifolder Will be set to True if multi-folder request
      *
      * @return array  List of message UIDs per folder
      */
