@@ -22,7 +22,7 @@
 /**
  * View class to produce JSON responses
  *
- * @package Webmail
+ * @package    Webmail
  * @subpackage View
  */
 class rcmail_output_json extends rcmail_output
@@ -43,10 +43,12 @@ class rcmail_output_json extends rcmail_output
      */
     public function set_pagetitle($title)
     {
-        if ($this->config->get('devel_mode') && !empty($_SESSION['username']))
+        if ($this->config->get('devel_mode') && !empty($_SESSION['username'])) {
             $name = $_SESSION['username'];
-        else
+        }
+        else {
             $name = $this->config->get('product_name');
+        }
 
         $this->command('set_pagetitle', empty($name) ? $title : $name . ' :: ' . $title);
     }
@@ -54,8 +56,8 @@ class rcmail_output_json extends rcmail_output
     /**
      * Register a template object handler
      *
-     * @param  string $obj Object name
-     * @param  string $func Function name to call
+     * @param string $obj  Object name
+     * @param string $func Function name to call
      */
     public function add_handler($obj, $func)
     {
@@ -65,7 +67,7 @@ class rcmail_output_json extends rcmail_output
     /**
      * Register a list of template object handlers
      *
-     * @param  array $arr Hash array with object=>handler pairs
+     * @param array $arr Hash array with object=>handler pairs
      */
     public function add_handlers($arr)
     {
@@ -82,10 +84,12 @@ class rcmail_output_json extends rcmail_output
     {
         $cmd = func_get_args();
 
-        if (strpos($cmd[0], 'plugin.') === 0)
-          $this->callbacks[] = $cmd;
-        else
-          $this->commands[] = $cmd;
+        if (strpos($cmd[0], 'plugin.') === 0) {
+            $this->callbacks[] = $cmd;
+        }
+        else {
+            $this->commands[] = $cmd;
+        }
     }
 
     /**
@@ -94,8 +98,9 @@ class rcmail_output_json extends rcmail_output
     public function add_label()
     {
         $args = func_get_args();
-        if (count($args) == 1 && is_array($args[0]))
+        if (count($args) == 1 && is_array($args[0])) {
             $args = $args[0];
+        }
 
         foreach ($args as $name) {
             $this->texts[$name] = $this->app->gettext($name);
@@ -110,6 +115,7 @@ class rcmail_output_json extends rcmail_output
      * @param array   $vars     Key-value pairs to be replaced in localized text
      * @param boolean $override Override last set message
      * @param int     $timeout  Message displaying time in seconds
+     *
      * @uses self::command()
      */
     public function show_message($message, $type='notice', $vars=null, $override=true, $timeout=0)
@@ -142,8 +148,9 @@ class rcmail_output_json extends rcmail_output
     /**
      * Redirect to a certain url
      *
-     * @param mixed $p Either a string with the action or url parameters as key-value pairs
-     * @param int $delay Delay in seconds
+     * @param mixed $p     Either a string with the action or url parameters as key-value pairs
+     * @param int   $delay Delay in seconds
+     *
      * @see rcmail::url()
      */
     public function redirect($p = array(), $delay = 1)
@@ -166,8 +173,8 @@ class rcmail_output_json extends rcmail_output
     /**
      * Show error page and terminate script execution
      *
-     * @param int    $code     Error code
-     * @param string $message  Error message
+     * @param int    $code    Error code
+     * @param string $message Error message
      */
     public function raise_error($code, $message)
     {
@@ -184,12 +191,9 @@ class rcmail_output_json extends rcmail_output
     /**
      * Send an AJAX response with executable JS code
      *
-     * @param  string  $add Additional JS code
-     * @param  boolean True if output buffer should be flushed
-     * @return void
-     * @deprecated
+     * @param string $add Additional JS code
      */
-    protected function remote_response($add='')
+    protected function remote_response($add = '')
     {
         static $s_header_sent = false;
 
@@ -228,13 +232,11 @@ class rcmail_output_json extends rcmail_output
         $response = $hook['response'];
         unset($hook['response']);
 
-        echo self::json_serialize($response);
+        echo self::json_serialize($response, $this->devel_mode);
     }
 
     /**
      * Return executable javascript code for all registered commands
-     *
-     * @return string $out
      */
     protected function get_js_commands()
     {
@@ -243,7 +245,7 @@ class rcmail_output_json extends rcmail_output
         foreach ($this->commands as $i => $args) {
             $method = array_shift($args);
             foreach ($args as $i => $arg) {
-                $args[$i] = self::json_serialize($arg);
+                $args[$i] = self::json_serialize($arg, $this->devel_mode);
             }
 
             $out .= sprintf(
